control_flow Package
====================

:mod:`control_flow` Package
---------------------------

.. automodule:: numba.control_flow
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`block` Module
-------------------

.. automodule:: numba.control_flow.block
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`cfstats` Module
---------------------

.. automodule:: numba.control_flow.cfstats
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`control_flow` Module
--------------------------

.. automodule:: numba.control_flow.control_flow
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`debug` Module
-------------------

.. automodule:: numba.control_flow.debug
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`delete_cfnode` Module
---------------------------

.. automodule:: numba.control_flow.delete_cfnode
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`graphviz` Module
----------------------

.. automodule:: numba.control_flow.graphviz
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`reaching` Module
----------------------

.. automodule:: numba.control_flow.reaching
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ssa` Module
-----------------

.. automodule:: numba.control_flow.ssa
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    numba.control_flow.tests

